==> haskell-puremd5-2.1.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.4
visibility:           public
id:                   pureMD5-2.1.4-HYMj1DdLn3uD88vdszVgzJ
key:                  pureMD5-2.1.4-HYMj1DdLn3uD88vdszVgzJ
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  f7424ee4e6faa9fcbf5897ac012cb572
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pureMD5-2.1.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pureMD5-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pureMD5-2.1.4
hs-libraries:         HSpureMD5-2.1.4-HYMj1DdLn3uD88vdszVgzJ
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7
    crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puremd5-2.1.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.4
visibility:           public
id:                   pureMD5-2.1.4-1H4TeX3AzOd3ppHXyeambo
key:                  pureMD5-2.1.4-1H4TeX3AzOd3ppHXyeambo
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  3b6a300132e8f5b37e758e67c988a5ce
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pureMD5-2.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pureMD5-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puremd5
hs-libraries:         HSpureMD5-2.1.4-1H4TeX3AzOd3ppHXyeambo
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-EHPdhbKdFzpJPwJ37IaBSu
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
